package admin

import (
	"cls-server/internal/domain/admin"
	"cls-server/pkg/xorm_engine"
	"errors"
	"fmt"
	"xorm.io/builder"
)

type AdminRepositoryORM struct {
	engine *xorm_engine.Engine
}

var _ admin.AdminRepository = (*AdminRepositoryORM)(nil)

func NewAdminRepositoryORM(engine *xorm_engine.Engine) admin.AdminRepository {
	return &AdminRepositoryORM{engine}
}

func (a *AdminRepositoryORM) Create(data *admin.Admin) error {
	i, err := a.engine.Insert(data)
	if err != nil {
		return err
	}
	if i == 0 {
		return errors.New("插入数据失败")
	}
	return nil
}

func (a *AdminRepositoryORM) FindAdminByUsername(username string) (*admin.Admin, error) {
	adminUser := &admin.Admin{}
	has, err := a.engine.Where(builder.Eq{"username": username}).Get(adminUser)
	if err != nil {
		return nil, err
	}
	if !has {
		return nil, errors.New(fmt.Sprintf("管理员名称【%s】未找到", username))
	}
	return adminUser, nil
}

func (a *AdminRepositoryORM) FindAdminByPhone(phone string) (*admin.Admin, error) {
	adminUser := &admin.Admin{}
	has, err := a.engine.Where(builder.Eq{"phone": phone}).Get(adminUser)
	if err != nil {
		return nil, err
	}
	if !has {
		return nil, errors.New(fmt.Sprintf("管理员手机号【%s】未找到", phone))
	}
	return adminUser, nil
}

func (a *AdminRepositoryORM) UpdatePassword(data *admin.Admin) error {
	_, err := a.engine.Where(builder.Eq{"username": data.Username}).Cols("password").Update(data)
	return err
}

func (a *AdminRepositoryORM) UpdatePhone(data *admin.Admin) error {
	_, err := a.engine.Where(builder.Eq{"username": data.Username}).Cols("phone").Update(data)
	return err
}
