package user

import (
	"cls-server/internal/domain/gift_log"
	"cls-server/internal/domain/user"
	"cls-server/pkg/xorm_engine"
	"errors"
	"fmt"
	"xorm.io/builder"
)

type UserGiftLogAggregateRepositoryORM struct {
	engine *xorm_engine.Engine
}

var _ user.UserGiftLogAggregateRepository = (*UserGiftLogAggregateRepositoryORM)(nil)

func NewUserGiftLogAggregateRepositoryORM(engine *xorm_engine.Engine) user.UserGiftLogAggregateRepository {
	return &UserGiftLogAggregateRepositoryORM{engine}
}

func (u *UserGiftLogAggregateRepositoryORM) GetUserGiftLogAggregate(userId uint64) (*user.UserGiftLogAggregate, error) {
	nU := &user.User{}
	has, err := u.engine.Where(builder.Eq{"id": userId}).Get(nU)
	if err != nil {
		return nil, err
	}
	if !has {
		return nil, errors.New(fmt.Sprintf("用户【%d】未找到 ", userId))
	}
	giftLogs := make([]*gift_log.GiftLog, 0)
	err = u.engine.Where(builder.Eq{"user_id": userId}).Find(&giftLogs)
	if err != nil {
		return nil, err
	}
	aggregate := user.NewUserGiftLogAggregate(nU)
	aggregate.SetGiftLogs(giftLogs)
	return aggregate, nil

}

func (u *UserGiftLogAggregateRepositoryORM) SaveUserGiftLogAggregate(aggregate *user.UserGiftLogAggregate) error {
	session := u.engine.NewSession()
	err := session.Begin()
	if err != nil {
		return err
	}
	defer session.Close()
	for _, v := range aggregate.GetGiftLogs() {
		if v.Id < 1 {
			_, err = session.Insert(v)
			if err != nil {
				return err
			}
		}
	}
	nU := aggregate.GetUser()
	_, err = session.Cols("gift_count").Update(nU)
	return session.Commit()
}
