package web

import (
	"fmt"
	"strings"
	"xorm.io/builder"
)

func ParseFiltersWithTableName(params map[string]string, tableName string) []builder.Cond {
	conds := make([]builder.Cond, 0)
	for k, v := range params {
		if v == "" {
			continue
		}
		keys := strings.SplitN(k, "_", 3)
		field := keys[2]
		if tableName != "" {
			field = fmt.Sprintf("%s.%s", tableName, field)
		}
		switch keys[1] {
		case "like":
			conds = append(conds, builder.Like{field, v})
		case "eq":
			conds = append(conds, builder.Eq{field: v})
		case "gt":
			conds = append(conds, builder.Gt{field: v})
		case "gte":
			conds = append(conds, builder.Gte{field: v})
		case "lt":
			conds = append(conds, builder.Lt{field: v})
		case "lte":
			conds = append(conds, builder.Lte{field: v})
		case "btw":
			conds = append(conds, builder.Between{
				Col:     field,
				LessVal: strings.SplitN(v, ",", 2)[0],
				MoreVal: strings.SplitN(v, ",", 2)[1],
			})
		default:
		}
	}
	return conds
}

func ParseFilters(params map[string]string) []builder.Cond {
	conds := make([]builder.Cond, 0)
	for k, v := range params {
		if v == "" {
			continue
		}
		keys := strings.SplitN(k, "_", 3)
		field := keys[2]
		switch keys[1] {
		case "like":
			conds = append(conds, builder.Like{field, v})
		case "eq":
			conds = append(conds, builder.Eq{field: v})
		case "gt":
			conds = append(conds, builder.Gt{field: v})
		case "gte":
			conds = append(conds, builder.Gte{field: v})
		case "lt":
			conds = append(conds, builder.Lt{field: v})
		case "lte":
			conds = append(conds, builder.Lte{field: v})
		case "btw":
			conds = append(conds, builder.Between{
				Col:     field,
				LessVal: strings.SplitN(v, ",", 2)[0],
				MoreVal: strings.SplitN(v, ",", 2)[1],
			})
		default:
		}
	}
	return conds
}
