import { Component, OnInit, OnDestroy, Input, Output, EventEmitter, ChangeDetectorRef } from '@angular/core';
import { FormGroup } from '@angular/forms';
import { HttpClient, HttpParams } from '@angular/common/http';
import { Subject } from 'rxjs';
import { takeUntil, delay } from 'rxjs/operators';
import {NzButtonComponent} from 'ng-zorro-antd/button';
import {AuthService} from "../../../core/auth/auth.service";
import {NzSpinComponent} from "ng-zorro-antd/spin";
import {NzImageDirective, NzImageModule, NzImageService} from "ng-zorro-antd/image";
import {CommonModule} from "@angular/common";

@Component({
  selector: 'app-image-captcha',
  standalone: true,
  imports: [
    NzSpinComponent,
    NzImageDirective,
    NzButtonComponent,
    CommonModule,
    NzImageModule,
  ],
  templateUrl: './image-captcha.component.html',
  styleUrls: ['./image-captcha.component.css']
})
export class ImageCaptchaComponent {

  loading = false;
  imageData: string | null = null;
  @Input() validateForm!: FormGroup;
  @Input() disable: boolean = false;
  @Input() width: number = 334;
  @Output() isImageData = new EventEmitter<boolean>();
  destroy$ = new Subject();

  constructor(private http: HttpClient, private cdr: ChangeDetectorRef, private authService: AuthService) {
    this.authService.onReset.pipe(takeUntil(this.destroy$)).subscribe(res => {
      this.loadData();
    });
    this.authService.onCheckAccountSuccess.pipe(takeUntil(this.destroy$)).subscribe(res => {
      this.imageData = null;
      this.isImageData.emit(true);
    });
  }

  ngOnInit(): void {
    this.loadData();
  }

  ngOnDestroy() {
    // this.destroy$.next();
    this.destroy$.complete();
  }

  loadData(): void {
    const username = this.validateForm.controls['username'].value;
    if (username == null || username == '') {
    } else {
      this.loading = true;
      this.cdr.detectChanges();
      let params = new HttpParams();
      if (username != null) {
        params = params.append('u', username);
      }
      this.http.get('/api/auth/image-captcha', {params, responseType: 'text'}).pipe(delay(500)).subscribe(imageData => {
        this.imageData = imageData;
        if (imageData.trim() === '') {
          this.isImageData.emit(true);
        } else {
          this.isImageData.emit(false);
        }
        this.loading = false;
        this.cdr.markForCheck();
      }, error => {
        this.loading = false;
        this.cdr.markForCheck();
      });
    }
  }
}
