import {ChangeDetectorRef, Component, OnInit} from '@angular/core';
import { FormBuilder, FormGroup, Validators, ReactiveFormsModule } from '@angular/forms';
import { NzFormModule } from 'ng-zorro-antd/form';
import { NzInputModule } from 'ng-zorro-antd/input';
import { NzButtonModule } from 'ng-zorro-antd/button';
import { NzCheckboxModule } from 'ng-zorro-antd/checkbox';
import { NzCardModule } from 'ng-zorro-antd/card';
import { NzSpaceModule } from 'ng-zorro-antd/space';
import { NzTypographyModule } from 'ng-zorro-antd/typography';
import { NzIconModule } from 'ng-zorro-antd/icon';
import { NzMessageService } from 'ng-zorro-antd/message';
import {ImageCaptchaComponent} from "./image-captcha/image-captcha.component";
import {CommonModule} from "@angular/common";
import {CaptchaResp} from "../../core/models/captcha";
import {AuthService} from "../../core/auth/auth.service";
import {Router} from "@angular/router";
import {NzModalModule} from "ng-zorro-antd/modal";

@Component({
  selector: 'app-login-form',
  standalone: true,
  imports: [
    ReactiveFormsModule,
    NzFormModule,
    NzInputModule,
    NzButtonModule,
    NzCheckboxModule,
    NzCardModule,
    NzSpaceModule,
    NzTypographyModule,
    NzIconModule,
    ImageCaptchaComponent,
    CommonModule,
    NzModalModule,
  ],
  templateUrl: './login-form.component.html',
  styleUrls: ['./login-form.component.css']
})
export class LoginFormComponent implements OnInit {
  loginForm!: FormGroup;
  isLoading = false;
  countdown = 0;
  captchaResp: CaptchaResp | null = null;

  constructor(
    private fb: FormBuilder,
    private message: NzMessageService,
    private authService:AuthService,
    private cdr:ChangeDetectorRef,
    private router: Router,

  ) {
    this.loginForm = this.fb.group({
      username: [null, [Validators.required, Validators.minLength(3)]],
      password: [null, [Validators.required]],
      smsCode: [null, [Validators.required, Validators.pattern('^\\d{6}$')]],
      imageCode: [null, [Validators.required]],
      remember: [false]
    });
  }

  ngOnInit(): void {

  }

  startCountdown(): void {
    this.countdown = 60;
    const timer = setInterval(() => {
      this.countdown--;
      if (this.countdown <= 0) {
        clearInterval(timer);
      }
    }, 1000);
  }

  sendSmsCode(): void {
    if (this.countdown > 0) return;
    // TODO: 调用发送短信验证码的API
    this.authService.getCaptcha(this.loginForm.controls['username'].value.trim()).subscribe(
      {
        next:data=>{
          console.log("进来")
          this.loginForm.controls['captcha'].reset();
          this.captchaResp = data;
          this.countdown = data.resetAfter;
          this.cdr.markForCheck();
          this.startCountdown();
          this.message.success('验证码已发送');
        },
        error: error=>{
          console.log(error)
          this.captchaResp = {status: 1, msg: '服务异常', resetAfter: 0};
          this.cdr.markForCheck();
          this.message.error('验证码发送失败');
        },
        complete: () => {
          setTimeout(() => {
            this.captchaResp = null;
            this.cdr.markForCheck();
          }, 3000)
        }
      })
  }

  captchaInValid(): boolean {
    return this.loginForm.controls['username'].invalid;
  }
  submitForm(): void {
    if (this.loginForm.valid) {
      this.isLoading = true;
      // TODO: 调用登录API
      this.authService.login(this.loginForm.value).subscribe((token)=>{
        sessionStorage.setItem('token', token);
        this.isLoading = false;
        this.cdr.detectChanges();
        this.router.navigate(['/']);
      })
      console.log('submit', this.loginForm.value);
      setTimeout(() => {
        this.isLoading = false;
      }, 1000);
    } else {
      Object.values(this.loginForm.controls).forEach(control => {
        if (control.invalid) {
          control.markAsTouched();
          control.updateValueAndValidity({ onlySelf: true });
        }
      });
    }
  }
}
