/* tslint:disable:no-bitwise */
import {HttpClient, HttpParams} from '@angular/common/http';
import {Injectable} from '@angular/core';
import {EMPTY, Observable, of, Subject} from 'rxjs';
import {JwtHelper} from '../jwt/auth.jwt';
import {map} from 'rxjs/operators';

import {CaptchaResp} from '../models/captcha';
import {LoginRequest, UserDetail} from "../models/admin";
import {aseEncrypt} from "../security/security.util";

@Injectable({
  providedIn: 'root'
})
export class AuthService {

  onReset = new Subject<any>();

  onCheckAccountSuccess = new Subject<any>();


  constructor(private http: HttpClient) {
  }

  login(loginRequest: LoginRequest): Observable<string> {
    // const credentials = {
    //   auth: aseEncrypt(JSON.stringify(loginRequest))
    // };
    return this.http.post<string>('/api/auth/login', loginRequest)
  }

  public valiateUserAndPhone(user: any): Observable<any> {
    const credentials = {
      user: aseEncrypt(JSON.stringify(user))
    };
    return this.http.post('/api/auth/check', credentials);
  }

  public radomPassword(): Observable<string> {
    return this.http.get('/api/auth/radom-password', {responseType: 'text'})
  }

  getCaptcha(name: string): Observable<CaptchaResp> {
    console.log("getCaptcha")
    const params = new HttpParams().append('username', name)
    return this.http.get<CaptchaResp>('/api/auth/captcha', {params});
  }

  public resetPassword(user: any): Observable<void> {
    const credentials = {
      user: aseEncrypt(JSON.stringify(user))
    };
    return this.http.post<void>('/auth/updatePassword', credentials);
  }

  public checkRoleAccess(rolesToCheckFor?: string[]): Observable<boolean> {
    if (rolesToCheckFor == null) {
      return of(false);
    }
    return getUser().pipe(
      map(user => user.roles == null ? [] : user.roles.map(role => role.role)),
      map(roles => this.canAccess(roles, rolesToCheckFor))
    );
  }

  private canAccess(appRoles: string[], rolesToCheckFor: string[]): boolean {
    if (appRoles && appRoles.length > 0) {
      const foundRole = appRoles.find(securityInfoRole => {
        return !!rolesToCheckFor.find(passedInRole => securityInfoRole === passedInRole);
      });
      return !!foundRole;
    } else {
      return false;
    }
  }
}

export const getLoggedIn = () => {
  const token: string | null = sessionStorage.getItem('token');
  const jwtHelper = new JwtHelper();
  return of(token != null && !jwtHelper.isTokenExpired(token));
};
export const getUser = (): Observable<UserDetail> => {
  const jwtHelper = new JwtHelper();
  const token = sessionStorage.getItem('token');
  if (token != null) {
    const userObj = jwtHelper.decodeToken(token);
    return of({
      id: userObj.id,
      roles: userObj.roles,
      username: userObj.username,
    } as UserDetail);
  } else {
    return EMPTY
  }
};
