import { HttpInterceptorFn } from '@angular/common/http';
import {NzModalService} from "ng-zorro-antd/modal";
import {inject, Injector} from "@angular/core";
import {Router} from "@angular/router";
import {AuthConfigConsts, tokenNotExpired} from "../jwt/auth.jwt";
import {of} from "rxjs";

export const authInterceptor: HttpInterceptorFn = (req, next) => {
  const injector = inject(Injector); // ✅ 先获取 Injector
  const modal = injector.get(NzModalService); // ✅ 运行时获取 NzModalService
  const router = injector.get(Router); // ✅ 运行时获取 Router
  const token = sessionStorage.getItem('token');
  let authHeader = req.headers;
  if (token != null && tokenNotExpired()) {
    const bearer = AuthConfigConsts.HEADER_PREFIX_BEARER + token;
    authHeader = authHeader.set(AuthConfigConsts.DEFAULT_HEADER_NAME, bearer);
  } else {
    if (!router.isActive('/auth', { paths: 'subset', queryParams: 'ignored', matrixParams: 'ignored' ,fragment:'ignored'})) {
      modal.closeAll();
      setTimeout(() => {
        modal.confirm({
          nzTitle: '会话失效,请重新登录!',
          nzOnOk: () => {
            modal.closeAll();
            router.navigate(['/auth/login']);
          }
        });
      });
      return of();
    }
  }
  const clonedRequest = req.clone({
    headers: authHeader
  });
  return next(clonedRequest);
};
