import {HttpHeaders, HttpParams} from '@angular/common/http';

/**
 * Contains common HTTP-related helper methods.
 *
 * @author Gunnar Hillert
 */
export class HttpUtils {

  public static getDefaultHttpHeaders() {
    return new HttpHeaders({
      'Content-Type': 'application/json',
      Accept: 'application/json'
    });
  }

  public static getPaginationParams(page: number, size: number): HttpParams {
    return new HttpParams()
      .append('page', page.toString())
      .append('size', size.toString());
  }

  public static getSearchParams(searchParams: { [key: string]: string }): HttpParams {
    let params = new HttpParams();
    for (const key of Object.keys(searchParams)) {
      const value = searchParams[key];
      if (value != null && value !== '') {
        params = params.append(key, value);
      }
    }
    return params
  }
}
