import {ChangeDetectorRef, Component, OnInit} from '@angular/core';

import { NzBreadCrumbModule } from 'ng-zorro-antd/breadcrumb';
import { NzPageHeaderModule } from 'ng-zorro-antd/page-header';
import {NzContentComponent} from "ng-zorro-antd/layout";
import {NzCardComponent, NzCardModule} from "ng-zorro-antd/card";
import {NzSpaceComponent, NzSpaceModule} from "ng-zorro-antd/space";
import {NzInputGroupComponent, NzInputModule} from "ng-zorro-antd/input";
import {debounceTime, distinctUntilChanged, fromEvent, Subject} from "rxjs";
import {take, takeUntil} from "rxjs/operators";
import {ColumnService} from "./column.service";
import {NzMessageService} from "ng-zorro-antd/message";
import {Column} from "../../core/models/column";
import {Page} from "../../core/models/page";
import {FormsModule} from "@angular/forms";
import { NzButtonModule} from "ng-zorro-antd/button";
import { NzListModule} from "ng-zorro-antd/list";
import {NzColDirective, NzGridModule, NzRowDirective} from "ng-zorro-antd/grid";
import {NzAvatarModule} from "ng-zorro-antd/avatar";
import {NzPaginationComponent} from "ng-zorro-antd/pagination";
import {NgFor} from "@angular/common";
import {EditColumnComponent} from "./edit-column/edit-column.component";
import {NzModalService} from "ng-zorro-antd/modal";

@Component({
  selector: 'app-column',
  standalone: true,
  imports: [
    NzBreadCrumbModule,
    NzPageHeaderModule,
    NzCardModule,
    NzSpaceModule,
    NzInputModule,
    FormsModule,
    NzButtonModule,
    NzRowDirective,
    NzAvatarModule,
    NzColDirective,
    NzPaginationComponent,
    NzCardModule, NzGridModule, NzListModule,
    NgFor,
  ],
  templateUrl: './column.component.html'
})
export class ColumnComponent implements OnInit{
  searchParams: { [param: string]: any } = {
    page: 0,
    size: 10,
    search_like_title: '',
  };
  onValueChange = new Subject<string>();
  destroy$ = new Subject();
  pageData: Page<Column> = new Page<Column>();
  loading = false;
  nzSpan = 12
  constructor(private cdr:ChangeDetectorRef,
              private message: NzMessageService,
              private modalService: NzModalService,
              private columnService:ColumnService) {
    this.onValueChange.pipe(
      debounceTime(20),
      distinctUntilChanged(),
      takeUntil(this.destroy$)).subscribe(() => {
      this.searchParams['page'] = 0;

      this.cdr.markForCheck();
      this.loadData();
    });
  }
  ngOnInit() {
    this.loadData()
    let width = window.innerWidth
    if (width < 1920) {
      this.nzSpan = 24
      this.cdr.detectChanges()
    } else {
      this.nzSpan = 12
      this.cdr.detectChanges()
    }
    fromEvent(window, 'resize').subscribe((v: any) => {
      let width = v.target.innerWidth
      if (width < 1920) {
        this.nzSpan = 24
        this.cdr.detectChanges()
      } else {
        this.nzSpan = 12
        this.cdr.detectChanges()
      }
    })
  }

  loadData(){
    this.loading = true;
    this.cdr.detectChanges();
    this.columnService.page(this.searchParams).pipe(takeUntil(this.destroy$)).subscribe(
      {
        next:data=>{
          this.pageData = data;
          this.loading = false;
          this.cdr.detectChanges();
        },
        error:data => {
          this.message.error("获取专栏数据失败，请稍后重试!")
          this.loading = false;
          this.cdr.detectChanges();
        }
      }
    )
  }
  /**
   * Update event from the Paginator Pager
   * @Param page
   */
  changePaginationPage(page: number): void {
    this.searchParams['page'] = page - 1;
    this.cdr.detectChanges();
    this.loadData();
  }

  /**
   * Update event from the Paginator Pager
   * @Param size
   */
  changePaginationSize(size: number): void {
    this.searchParams['page'] = 0;
    this.searchParams['size'] = size;
    this.cdr.detectChanges();
    this.loadData();
  }

  editColumn(column: Column) {
    console.log(column)
    const modal = this.modalService.create({
      nzTitle: `更新基本信息`,
      nzContent: EditColumnComponent,
      nzMaskClosable: false,
      nzClosable: false,
      nzData:{column:column},
      nzFooter: [
        {
          label: '取消',
          onClick: componentInstance => componentInstance!.handleCancel()
        },
        {
          label: '确定',
          type: 'primary',
          loading: componentInstance => componentInstance!.isSaving,
          onClick: componentInstance => componentInstance!.handleOk(),
          disabled: componentInstance => !componentInstance!.validateForm.valid
        }
      ]
    })
    modal.afterClose.subscribe(result => {
      if (result != null) {
        this.loadData();
      }
    });
  }
}
