import {Component, Input, OnInit} from '@angular/core';
import {Column} from "../../../core/models/column";
import {FormBuilder, FormGroup, ReactiveFormsModule, Validators} from "@angular/forms";
import {NzModalRef} from "ng-zorro-antd/modal";
import {ColumnService} from "../column.service";
import {NzMessageService} from "ng-zorro-antd/message";
import {NzColDirective, NzRowDirective} from "ng-zorro-antd/grid";
import { NzFormModule } from 'ng-zorro-antd/form';
import {NzInputDirective} from "ng-zorro-antd/input";
@Component({
  selector: 'app-edit-column',
  standalone: true,
  imports: [
    ReactiveFormsModule,
    NzRowDirective,
    NzColDirective,
    NzFormModule,
    NzInputDirective
  ],
  templateUrl: './edit-column.component.html',
  styleUrl: './edit-column.component.scss'
})
export class EditColumnComponent implements  OnInit{
  @Input() column!:Column
  isSaving:boolean = false
  validateForm!: FormGroup;
  constructor(private fb:FormBuilder,
              private modal:NzModalRef,
              private columnService:ColumnService,
              private message:NzMessageService) {

  }
  ngOnInit(): void {
    console.log(this.column)
    this.validateForm = this.fb.group({
      id:[null,[Validators.required]],
      title:[null,[Validators.required]],
      brief:[null,[Validators.required]],
      cover:[null],
      followNum:[null,[Validators.required]],
      purchaseNum:[null,[Validators.required]]
    })
    console.log('validateForm 初始化成功:', this.validateForm);
    // if(this.column != null) {
    //   this.validateForm.patchValue(this.column);
    //
    // }
  }
  handleOk(): void {
    //tslint:disable-next-line:forin
    for (const i in this.validateForm.controls) {
      this.validateForm.controls[i].markAsDirty();
    }
    if (this.validateForm.valid) {
      this.isSaving = true;
      this.columnService.save(this.validateForm.value).subscribe(() => {
        this.isSaving = false;
        this.message.success('保存成功');
        this.modal.close('success');
      }, (err) => {
        this.message.error('保存失败');
        this.isSaving = false;
      });
    }
  }

  handleCancel(): void {
    this.modal.destroy();
  }


}
