import { Component, Inject, OnInit } from '@angular/core';
import { FormBuilder, FormGroup, Validators, FormsModule, ReactiveFormsModule } from '@angular/forms';
import { UserInfo } from '../../../core/models/user';
import { NZ_MODAL_DATA, NzModalRef } from 'ng-zorro-antd/modal';
import { NzFormModule } from 'ng-zorro-antd/form';
import { NzInputModule } from 'ng-zorro-antd/input';
import { NzInputNumberModule } from 'ng-zorro-antd/input-number';
import { NzButtonModule } from 'ng-zorro-antd/button';
import { CommonModule } from '@angular/common';

export interface GiftModalData {
  user: UserInfo;
}

@Component({
  selector: 'app-gift',
  standalone: true,
  imports: [
    CommonModule,
    FormsModule,
    ReactiveFormsModule,
    NzFormModule,
    NzInputModule,
    NzInputNumberModule,
    NzButtonModule
  ],
  template: `
    <div class="gift-form">
      <form nz-form [formGroup]="validateForm">
        <nz-form-item>
          <nz-form-label [nzSpan]="8" nzRequired>用户</nz-form-label>
          <nz-form-control [nzSpan]="16">
            <span class="user-info">
              {{ userData.user.username }} ({{ userData.user.phone }})
            </span>
          </nz-form-control>
        </nz-form-item>

        <nz-form-item>
          <nz-form-label [nzSpan]="8" nzRequired>赠送解锁次数</nz-form-label>
          <nz-form-control [nzSpan]="16" [nzErrorTip]="countError">
            <nz-input-number 
              formControlName="unlockCount" 
              [nzMin]="1" 
              [nzMax]="5"
              [nzStep]="1"
              [nzPrecision]="0"
              [nzPlaceHolder]="'请输入解锁次数'">
            </nz-input-number>
            <span class="hint-text">（1-5次）</span>
          </nz-form-control>
          <ng-template #countError let-control>
            <ng-container *ngIf="control.hasError('required')">
              请输入解锁次数
            </ng-container>
            <ng-container *ngIf="control.hasError('min')">
              解锁次数不能少于1次
            </ng-container>
            <ng-container *ngIf="control.hasError('max')">
              解锁次数不能超过5次
            </ng-container>
          </ng-template>
        </nz-form-item>
      </form>
    </div>
  `,
  styles: [`
    .gift-form {
      padding: 20px 0;
    }
    
    .user-info {
      font-weight: 500;
    }

    nz-input-number {
      width: 100%;
    }

    .hint-text {
      color: #999;
      margin-left: 8px;
      font-size: 12px;
    }
  `]
})
export class GiftComponent implements OnInit {
  validateForm!: FormGroup;

  constructor(
    private fb: FormBuilder,
    private modalRef: NzModalRef,
    @Inject(NZ_MODAL_DATA) public userData: GiftModalData
  ) { }

  ngOnInit(): void {
    this.validateForm = this.fb.group({
      unlockCount: [1, [Validators.required, Validators.min(1), Validators.max(5)]]
    });
  }

  // 提交数据
  submitForm(): { unlockCount: number } | null {
    if (this.validateForm.valid) {
      return this.validateForm.value;
    }
    
    // 标记所有字段为已触摸，显示验证错误
    Object.values(this.validateForm.controls).forEach(control => {
      if (control.invalid) {
        control.markAsTouched();
        control.updateValueAndValidity({ onlySelf: true });
      }
    });
    
    return null;
  }
} 