import { Injectable } from '@angular/core';
import {HttpClient} from "@angular/common/http";
import {Observable} from "rxjs";
import {extractData, Page} from "../../core/models/page";
import {Column} from "../../core/models/column";
import {HttpUtils} from "../../core/until/http.utils";
import {map} from "rxjs/operators";
import {UserInfo} from "../../core/models/user";
import {Gift} from "../../core/models/gift";
import {Coupon} from "../../core/models/coupon";

@Injectable({
  providedIn: 'root'
})
export class UserService {

  constructor(private http:HttpClient) { }


  page(searchParams: { [key: string]: string }):Observable<Page<UserInfo>>{
    return this.http.get<Page<UserInfo>>('/api/user/page',{params:HttpUtils.getSearchParams(searchParams)}).pipe(
      map(response=> extractData<UserInfo>(response))
    )
  }
  giveGift(gift:Gift):Observable<null>{
    return this.http.post<null>('/api/user/give-gift',gift)
  }
  giveCoupon(coupon:Coupon):Observable<null>{
    return this.http.post<null>('/api/user/give-coupon',coupon)
  }

  enableUser(id:number):Observable<null> {
    return this.http.post<null>(`/api/user/enable/${id}`, {})
  }
  disableUser(id:number):Observable<null> {
    return this.http.post<null>(`/api/user/disable/${id}`, {})
  }
}
